# openiti

This is a first attempt to create a Python library that combines all often-used code in the OpenITI project. 

Change log: 
v.0.0.4: 
* openiti.helper.uri: removed the restriction on the use of digits in book titles
* openiti.helper.uri: added a check for empty yml files
* openiti.helper.yml: added documentation and doctests
* openiti.helper.yml: added check for empty yml files + changed splitting of yml files so that even unindented multi-line values can be correctly parsed.
